Crate aws_sdk_eks[−][src]
Amazon Elastic Kubernetes Service (Amazon EKS) is a managed service that makes it easy for you to run Kubernetes on Amazon Web Services without needing to stand up or maintain your own Kubernetes control plane. Kubernetes is an open-source system for automating the deployment, scaling, and management of containerized applications.
Amazon EKS runs up-to-date versions of the open-source Kubernetes software, so you can use all the existing plugins and tooling from the Kubernetes community. Applications running on Amazon EKS are fully compatible with applications running on any standard Kubernetes environment, whether running in on-premises data centers or public clouds. This means that you can easily migrate any standard Kubernetes application to Amazon EKS without any code modification required.
Re-exports
Modules
Client and fluent builders for calling the service.
Configuration for the service.
Errors that can occur when calling the service.
Input structures for operations.
Data structures used by operation inputs/outputs.
All operations that this crate can perform.
Output structures for operations.
Structs
Binary Blob Type
Stream of binary data
AWS SDK Credentials
API Endpoint
The region to send requests to.
Retry configuration for requests.
Enums
Statics
Crate version number.