Struct aws_sdk_eks::client::fluent_builders::DescribeAddonVersions [−][src]
pub struct DescribeAddonVersions<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DescribeAddonVersions.
Describes the Kubernetes versions that the add-on can be used with.
Implementations
impl<C, M, R> DescribeAddonVersions<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DescribeAddonVersions<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DescribeAddonVersionsOutput, SdkError<DescribeAddonVersionsError>> where
R::Policy: SmithyRetryPolicy<DescribeAddonVersionsInputOperationOutputAlias, DescribeAddonVersionsOutput, DescribeAddonVersionsError, DescribeAddonVersionsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DescribeAddonVersionsOutput, SdkError<DescribeAddonVersionsError>> where
R::Policy: SmithyRetryPolicy<DescribeAddonVersionsInputOperationOutputAlias, DescribeAddonVersionsOutput, DescribeAddonVersionsError, DescribeAddonVersionsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The Kubernetes versions that the add-on can be used with.
The Kubernetes versions that the add-on can be used with.
The maximum number of results to return.
The maximum number of results to return.
The nextToken value returned from a previous paginated
DescribeAddonVersionsRequest where maxResults was used and
the results exceeded the value of that parameter. Pagination continues from the end of
the previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
The nextToken value returned from a previous paginated
DescribeAddonVersionsRequest where maxResults was used and
the results exceeded the value of that parameter. Pagination continues from the end of
the previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
The name of the add-on. The name must match one of the names returned by
ListAddons
.
The name of the add-on. The name must match one of the names returned by
ListAddons
.