Struct aws_sdk_eks::client::fluent_builders::DisassociateIdentityProviderConfig[][src]

pub struct DisassociateIdentityProviderConfig<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to DisassociateIdentityProviderConfig.

Disassociates an identity provider configuration from a cluster. If you disassociate an identity provider from your cluster, users included in the provider can no longer access the cluster. However, you can still access the cluster with Amazon Web Services IAM users.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the cluster to disassociate an identity provider from.

The name of the cluster to disassociate an identity provider from.

An object that represents an identity provider configuration.

An object that represents an identity provider configuration.

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.