Struct aws_sdk_eks::client::fluent_builders::ListClusters [−][src]
pub struct ListClusters<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to ListClusters.
Lists the Amazon EKS clusters in your Amazon Web Services account in the specified Region.
Implementations
impl<C, M, R> ListClusters<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> ListClusters<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<ListClustersOutput, SdkError<ListClustersError>> where
R::Policy: SmithyRetryPolicy<ListClustersInputOperationOutputAlias, ListClustersOutput, ListClustersError, ListClustersInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<ListClustersOutput, SdkError<ListClustersError>> where
R::Policy: SmithyRetryPolicy<ListClustersInputOperationOutputAlias, ListClustersOutput, ListClustersError, ListClustersInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The maximum number of cluster results returned by ListClusters in
paginated output. When you use this parameter, ListClusters returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListClusters request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListClusters returns up to 100
results and a nextToken value if applicable.
The maximum number of cluster results returned by ListClusters in
paginated output. When you use this parameter, ListClusters returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListClusters request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListClusters returns up to 100
results and a nextToken value if applicable.
The nextToken value returned from a previous paginated
ListClusters request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
The nextToken value returned from a previous paginated
ListClusters request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
Appends an item to include.
To override the contents of this collection use set_include.
Indicates whether connected clusters are included in the returned list. Default value is 'ALL'.
Indicates whether connected clusters are included in the returned list. Default value is 'ALL'.