Struct aws_sdk_eks::client::fluent_builders::RegisterCluster[][src]

pub struct RegisterCluster<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to RegisterCluster.

Connects a Kubernetes cluster to the Amazon EKS control plane.

Any Kubernetes cluster can be connected to the Amazon EKS control plane to view current information about the cluster and its nodes.

Cluster connection requires two steps. First, send a RegisterClusterRequest to add it to the Amazon EKS control plane.

Second, a Manifest containing the activationID and activationCode must be applied to the Kubernetes cluster through it's native provider to provide visibility.

After the Manifest is updated and applied, then the connected cluster is visible to the Amazon EKS control plane. If the Manifest is not applied within a set amount of time, then the connected cluster will no longer be visible and must be deregistered. See DeregisterCluster.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

Define a unique name for this cluster within your AWS account.

Define a unique name for this cluster within your AWS account.

The configuration settings required to connect the Kubernetes cluster to the Amazon EKS control plane.

The configuration settings required to connect the Kubernetes cluster to the Amazon EKS control plane.

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.