Enum aws_sdk_eks::Error[][src]

#[non_exhaustive]
pub enum Error {
    BadRequestException(BadRequestException),
    ClientException(ClientException),
    InvalidParameterException(InvalidParameterException),
    InvalidRequestException(InvalidRequestException),
    NotFoundException(NotFoundException),
    ResourceInUseException(ResourceInUseException),
    ResourceLimitExceededException(ResourceLimitExceededException),
    ResourceNotFoundException(ResourceNotFoundException),
    ServerException(ServerException),
    ServiceUnavailableException(ServiceUnavailableException),
    UnsupportedAvailabilityZoneException(UnsupportedAvailabilityZoneException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
All possible error types for this service.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadRequestException(BadRequestException)

This exception is thrown if the request contains a semantic error. The precise meaning will depend on the API, and will be documented in the error message.

Tuple Fields of BadRequestException

0: BadRequestException
ClientException(ClientException)

These errors are usually caused by a client action. Actions can include using an action or resource on behalf of a user that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.

Tuple Fields of ClientException

0: ClientException
InvalidParameterException(InvalidParameterException)

The specified parameter is invalid. Review the available parameters for the API request.

Tuple Fields of InvalidParameterException

0: InvalidParameterException
InvalidRequestException(InvalidRequestException)

The request is invalid given the state of the cluster. Check the state of the cluster and the associated operations.

Tuple Fields of InvalidRequestException

0: InvalidRequestException
NotFoundException(NotFoundException)

A service resource associated with the request could not be found. Clients should not retry such requests.

Tuple Fields of NotFoundException

0: NotFoundException
ResourceInUseException(ResourceInUseException)

The specified resource is in use.

Tuple Fields of ResourceInUseException

0: ResourceInUseException
ResourceLimitExceededException(ResourceLimitExceededException)

You have encountered a service limit on the specified resource.

Tuple Fields of ResourceLimitExceededException

0: ResourceLimitExceededException
ResourceNotFoundException(ResourceNotFoundException)

The specified resource could not be found. You can view your available clusters with ListClusters. You can view your available managed node groups with ListNodegroups. Amazon EKS clusters and node groups are Region-specific.

Tuple Fields of ResourceNotFoundException

0: ResourceNotFoundException
ServerException(ServerException)

These errors are usually caused by a server-side issue.

Tuple Fields of ServerException

0: ServerException
ServiceUnavailableException(ServiceUnavailableException)

The service is unavailable. Back off and retry the operation.

Tuple Fields of ServiceUnavailableException

0: ServiceUnavailableException
UnsupportedAvailabilityZoneException(UnsupportedAvailabilityZoneException)

At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS. The exception output specifies the supported Availability Zones for your account, from which you can choose subnets for your cluster.

Tuple Fields of UnsupportedAvailabilityZoneException

0: UnsupportedAvailabilityZoneException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unhandled error occurred.

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>