Enum aws_sdk_eks::error::CreateClusterErrorKind [−][src]
#[non_exhaustive]
pub enum CreateClusterErrorKind {
ClientException(ClientException),
InvalidParameterException(InvalidParameterException),
ResourceInUseException(ResourceInUseException),
ResourceLimitExceededException(ResourceLimitExceededException),
ServerException(ServerException),
ServiceUnavailableException(ServiceUnavailableException),
UnsupportedAvailabilityZoneException(UnsupportedAvailabilityZoneException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreateCluster operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ClientException(ClientException)These errors are usually caused by a client action. Actions can include using an action or resource on behalf of a user that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.
Tuple Fields of ClientException
InvalidParameterException(InvalidParameterException)The specified parameter is invalid. Review the available parameters for the API request.
Tuple Fields of InvalidParameterException
ResourceInUseException(ResourceInUseException)The specified resource is in use.
Tuple Fields of ResourceInUseException
ResourceLimitExceededException(ResourceLimitExceededException)You have encountered a service limit on the specified resource.
Tuple Fields of ResourceLimitExceededException
ServerException(ServerException)These errors are usually caused by a server-side issue.
Tuple Fields of ServerException
The service is unavailable. Back off and retry the operation.
UnsupportedAvailabilityZoneException(UnsupportedAvailabilityZoneException)At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS. The exception output specifies the supported Availability Zones for your account, from which you can choose subnets for your cluster.
Tuple Fields of UnsupportedAvailabilityZoneException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code