Enum aws_sdk_eks::error::CreateNodegroupErrorKind [−][src]
#[non_exhaustive]
pub enum CreateNodegroupErrorKind {
ClientException(ClientException),
InvalidParameterException(InvalidParameterException),
InvalidRequestException(InvalidRequestException),
ResourceInUseException(ResourceInUseException),
ResourceLimitExceededException(ResourceLimitExceededException),
ServerException(ServerException),
ServiceUnavailableException(ServiceUnavailableException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreateNodegroup operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ClientException(ClientException)These errors are usually caused by a client action. Actions can include using an action or resource on behalf of a user that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.
Tuple Fields of ClientException
InvalidParameterException(InvalidParameterException)The specified parameter is invalid. Review the available parameters for the API request.
Tuple Fields of InvalidParameterException
InvalidRequestException(InvalidRequestException)The request is invalid given the state of the cluster. Check the state of the cluster and the associated operations.
Tuple Fields of InvalidRequestException
ResourceInUseException(ResourceInUseException)The specified resource is in use.
Tuple Fields of ResourceInUseException
ResourceLimitExceededException(ResourceLimitExceededException)You have encountered a service limit on the specified resource.
Tuple Fields of ResourceLimitExceededException
ServerException(ServerException)These errors are usually caused by a server-side issue.
Tuple Fields of ServerException
The service is unavailable. Back off and retry the operation.
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code