Enum aws_sdk_eks::error::DescribeNodegroupErrorKind[][src]

#[non_exhaustive]
pub enum DescribeNodegroupErrorKind {
    ClientException(ClientException),
    InvalidParameterException(InvalidParameterException),
    ResourceNotFoundException(ResourceNotFoundException),
    ServerException(ServerException),
    ServiceUnavailableException(ServiceUnavailableException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the DescribeNodegroup operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ClientException(ClientException)

These errors are usually caused by a client action. Actions can include using an action or resource on behalf of a user that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.

Tuple Fields of ClientException

0: ClientException
InvalidParameterException(InvalidParameterException)

The specified parameter is invalid. Review the available parameters for the API request.

Tuple Fields of InvalidParameterException

0: InvalidParameterException
ResourceNotFoundException(ResourceNotFoundException)

The specified resource could not be found. You can view your available clusters with ListClusters. You can view your available managed node groups with ListNodegroups. Amazon EKS clusters and node groups are Region-specific.

Tuple Fields of ResourceNotFoundException

0: ResourceNotFoundException
ServerException(ServerException)

These errors are usually caused by a server-side issue.

Tuple Fields of ServerException

0: ServerException
ServiceUnavailableException(ServiceUnavailableException)

The service is unavailable. Back off and retry the operation.

Tuple Fields of ServiceUnavailableException

0: ServiceUnavailableException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>