Enum aws_sdk_eks::error::RegisterClusterErrorKind [−][src]
#[non_exhaustive]
pub enum RegisterClusterErrorKind {
AccessDeniedException(AccessDeniedException),
ClientException(ClientException),
InvalidParameterException(InvalidParameterException),
ResourceLimitExceededException(ResourceLimitExceededException),
ServerException(ServerException),
ServiceUnavailableException(ServiceUnavailableException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the RegisterCluster operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Tuple Fields
You don't have permissions to perform the requested operation. The user or role that is making the request must have at least one IAM permissions policy attached that grants the required permissions. For more information, see Access Management in the IAM User Guide.
ClientException(ClientException)
Tuple Fields
These errors are usually caused by a client action. Actions can include using an action or resource on behalf of a user that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.
InvalidParameterException(InvalidParameterException)
Tuple Fields
The specified parameter is invalid. Review the available parameters for the API request.
ResourceLimitExceededException(ResourceLimitExceededException)
Tuple Fields
You have encountered a service limit on the specified resource.
ServerException(ServerException)
Tuple Fields
These errors are usually caused by a server-side issue.
ServiceUnavailableException(ServiceUnavailableException)
The service is unavailable. Back off and retry the operation.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code