Struct aws_sdk_eks::input::list_clusters_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListClustersInput
Implementations
The maximum number of cluster results returned by ListClusters in
paginated output. When you use this parameter, ListClusters returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListClusters request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListClusters returns up to 100
results and a nextToken value if applicable.
The maximum number of cluster results returned by ListClusters in
paginated output. When you use this parameter, ListClusters returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListClusters request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListClusters returns up to 100
results and a nextToken value if applicable.
The nextToken value returned from a previous paginated
ListClusters request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
The nextToken value returned from a previous paginated
ListClusters request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
Appends an item to include.
To override the contents of this collection use set_include.
Indicates whether connected clusters are included in the returned list. Default value is 'ALL'.
Indicates whether connected clusters are included in the returned list. Default value is 'ALL'.
Consumes the builder and constructs a ListClustersInput