Struct aws_sdk_eks::input::list_updates_input::Builder[][src]

#[non_exhaustive]
pub struct Builder { /* fields omitted */ }
A builder for ListUpdatesInput

Implementations

The name of the Amazon EKS cluster to list updates for.

The name of the Amazon EKS cluster to list updates for.

The name of the Amazon EKS managed node group to list updates for.

The name of the Amazon EKS managed node group to list updates for.

The names of the installed add-ons that have available updates.

The names of the installed add-ons that have available updates.

The nextToken value returned from a previous paginated ListUpdates request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.

The nextToken value returned from a previous paginated ListUpdates request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.

The maximum number of update results returned by ListUpdates in paginated output. When you use this parameter, ListUpdates returns only maxResults results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListUpdates request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListUpdates returns up to 100 results and a nextToken value if applicable.

The maximum number of update results returned by ListUpdates in paginated output. When you use this parameter, ListUpdates returns only maxResults results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListUpdates request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListUpdates returns up to 100 results and a nextToken value if applicable.

Consumes the builder and constructs a ListUpdatesInput