Struct aws_sdk_eks::input::ListAddonsInput [−][src]
#[non_exhaustive]pub struct ListAddonsInput {
pub cluster_name: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_name: Option<String>The name of the cluster.
max_results: Option<i32>The maximum number of add-on results returned by ListAddonsRequest in
paginated output. When you use this parameter, ListAddonsRequest returns
only maxResults results in a single page along with a
nextToken response element. You can see the remaining results of the
initial request by sending another ListAddonsRequest request with the
returned nextToken value. This value can be between 1 and
100. If you don't use this parameter, ListAddonsRequest
returns up to 100 results and a nextToken value, if
applicable.
next_token: Option<String>The nextToken value returned from a previous paginated
ListAddonsRequest where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListAddons, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListAddons, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListAddons>
Creates a new builder-style object to manufacture ListAddonsInput
The name of the cluster.
The maximum number of add-on results returned by ListAddonsRequest in
paginated output. When you use this parameter, ListAddonsRequest returns
only maxResults results in a single page along with a
nextToken response element. You can see the remaining results of the
initial request by sending another ListAddonsRequest request with the
returned nextToken value. This value can be between 1 and
100. If you don't use this parameter, ListAddonsRequest
returns up to 100 results and a nextToken value, if
applicable.
The nextToken value returned from a previous paginated
ListAddonsRequest where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.