Struct aws_sdk_eks::input::ListClustersInput [−][src]
#[non_exhaustive]pub struct ListClustersInput {
pub max_results: Option<i32>,
pub next_token: Option<String>,
pub include: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_results: Option<i32>The maximum number of cluster results returned by ListClusters in
paginated output. When you use this parameter, ListClusters returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListClusters request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListClusters returns up to 100
results and a nextToken value if applicable.
next_token: Option<String>The nextToken value returned from a previous paginated
ListClusters request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
include: Option<Vec<String>>Indicates whether connected clusters are included in the returned list. Default value is 'ALL'.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListClusters, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListClusters, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListClusters>
Creates a new builder-style object to manufacture ListClustersInput
The maximum number of cluster results returned by ListClusters in
paginated output. When you use this parameter, ListClusters returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListClusters request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListClusters returns up to 100
results and a nextToken value if applicable.
The nextToken value returned from a previous paginated
ListClusters request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.