Struct aws_sdk_eks::input::ListIdentityProviderConfigsInput [−][src]
#[non_exhaustive]pub struct ListIdentityProviderConfigsInput {
pub cluster_name: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_name: Option<String>The cluster name that you want to list identity provider configurations for.
max_results: Option<i32>The maximum number of identity provider configurations returned by
ListIdentityProviderConfigs in paginated output. When you use this
parameter, ListIdentityProviderConfigs returns only maxResults
results in a single page along with a nextToken response element. You can
see the remaining results of the initial request by sending another
ListIdentityProviderConfigs request with the returned
nextToken value. This value can be between 1 and
100. If you don't use this parameter,
ListIdentityProviderConfigs returns up to 100 results
and a nextToken value, if applicable.
next_token: Option<String>The nextToken value returned from a previous paginated
IdentityProviderConfigsRequest where maxResults was used
and the results exceeded the value of that parameter. Pagination continues from the end
of the previous results that returned the nextToken value.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListIdentityProviderConfigs, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListIdentityProviderConfigs, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListIdentityProviderConfigs>
Creates a new builder-style object to manufacture ListIdentityProviderConfigsInput
The cluster name that you want to list identity provider configurations for.
The maximum number of identity provider configurations returned by
ListIdentityProviderConfigs in paginated output. When you use this
parameter, ListIdentityProviderConfigs returns only maxResults
results in a single page along with a nextToken response element. You can
see the remaining results of the initial request by sending another
ListIdentityProviderConfigs request with the returned
nextToken value. This value can be between 1 and
100. If you don't use this parameter,
ListIdentityProviderConfigs returns up to 100 results
and a nextToken value, if applicable.
The nextToken value returned from a previous paginated
IdentityProviderConfigsRequest where maxResults was used
and the results exceeded the value of that parameter. Pagination continues from the end
of the previous results that returned the nextToken value.