Struct aws_sdk_eks::input::ListNodegroupsInput [−][src]
#[non_exhaustive]pub struct ListNodegroupsInput {
pub cluster_name: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_name: Option<String>The name of the Amazon EKS cluster that you would like to list node groups in.
max_results: Option<i32>The maximum number of node group results returned by ListNodegroups in
paginated output. When you use this parameter, ListNodegroups returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListNodegroups request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListNodegroups returns up to 100
results and a nextToken value if applicable.
next_token: Option<String>The nextToken value returned from a previous paginated
ListNodegroups request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListNodegroups, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListNodegroups, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListNodegroups>
Creates a new builder-style object to manufacture ListNodegroupsInput
The name of the Amazon EKS cluster that you would like to list node groups in.
The maximum number of node group results returned by ListNodegroups in
paginated output. When you use this parameter, ListNodegroups returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListNodegroups request with the returned nextToken
value. This value can be between 1 and 100. If you don't
use this parameter, ListNodegroups returns up to 100
results and a nextToken value if applicable.
The nextToken value returned from a previous paginated
ListNodegroups request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.