Struct aws_sdk_eks::input::ListUpdatesInput [−][src]
#[non_exhaustive]pub struct ListUpdatesInput {
pub name: Option<String>,
pub nodegroup_name: Option<String>,
pub addon_name: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the Amazon EKS cluster to list updates for.
nodegroup_name: Option<String>The name of the Amazon EKS managed node group to list updates for.
addon_name: Option<String>The names of the installed add-ons that have available updates.
next_token: Option<String>The nextToken value returned from a previous paginated
ListUpdates request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
max_results: Option<i32>The maximum number of update results returned by ListUpdates in paginated
output. When you use this parameter, ListUpdates returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListUpdates request with the returned nextToken value.
This value can be between 1 and 100. If you don't use this
parameter, ListUpdates returns up to 100 results and a
nextToken value if applicable.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListUpdates, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListUpdates, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListUpdates>
Creates a new builder-style object to manufacture ListUpdatesInput
The name of the Amazon EKS managed node group to list updates for.
The names of the installed add-ons that have available updates.
The nextToken value returned from a previous paginated
ListUpdates request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
The maximum number of update results returned by ListUpdates in paginated
output. When you use this parameter, ListUpdates returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListUpdates request with the returned nextToken value.
This value can be between 1 and 100. If you don't use this
parameter, ListUpdates returns up to 100 results and a
nextToken value if applicable.