Struct aws_sdk_eks::input::RegisterClusterInput [−][src]
#[non_exhaustive]pub struct RegisterClusterInput {
pub name: Option<String>,
pub connector_config: Option<ConnectorConfigRequest>,
pub client_request_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>Define a unique name for this cluster for your Region.
connector_config: Option<ConnectorConfigRequest>The configuration settings required to connect the Kubernetes cluster to the Amazon EKS control plane.
client_request_token: Option<String>Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
The metadata that you apply to the cluster to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Cluster tags do not propagate to any other resources associated with the cluster.
Implementations
pub async fn make_operation(
self,
_config: &Config
) -> Result<Operation<RegisterCluster, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
self,
_config: &Config
) -> Result<Operation<RegisterCluster, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<RegisterCluster>
Creates a new builder-style object to manufacture RegisterClusterInput
The configuration settings required to connect the Kubernetes cluster to the Amazon EKS control plane.
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
The metadata that you apply to the cluster to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Cluster tags do not propagate to any other resources associated with the cluster.