Struct aws_sdk_eks::model::addon_issue::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for AddonIssue
Implementations
A code that describes the type of issue.
A code that describes the type of issue.
A message that provides details about the issue and what might cause it.
A message that provides details about the issue and what might cause it.
Appends an item to resource_ids.
To override the contents of this collection use set_resource_ids.
The resource IDs of the issue.
The resource IDs of the issue.
Consumes the builder and constructs a AddonIssue