Struct aws_sdk_eks::model::FargateProfile [−][src]
#[non_exhaustive]pub struct FargateProfile {
pub fargate_profile_name: Option<String>,
pub fargate_profile_arn: Option<String>,
pub cluster_name: Option<String>,
pub created_at: Option<DateTime>,
pub pod_execution_role_arn: Option<String>,
pub subnets: Option<Vec<String>>,
pub selectors: Option<Vec<FargateProfileSelector>>,
pub status: Option<FargateProfileStatus>,
pub tags: Option<HashMap<String, String>>,
}Expand description
An object representing an Fargate profile.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fargate_profile_name: Option<String>The name of the Fargate profile.
fargate_profile_arn: Option<String>The full Amazon Resource Name (ARN) of the Fargate profile.
cluster_name: Option<String>The name of the Amazon EKS cluster that the Fargate profile belongs to.
created_at: Option<DateTime>The Unix epoch timestamp in seconds for when the Fargate profile was created.
pod_execution_role_arn: Option<String>The Amazon Resource Name (ARN) of the pod execution role to use for pods that match the selectors in the Fargate profile. For more information, see Pod Execution Role in the Amazon EKS User Guide.
subnets: Option<Vec<String>>The IDs of subnets to launch pods into.
selectors: Option<Vec<FargateProfileSelector>>The selectors to match for pods to use this Fargate profile.
status: Option<FargateProfileStatus>The current status of the Fargate profile.
The metadata applied to the Fargate profile to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Fargate profile tags do not propagate to any other resources associated with the Fargate profile, such as the pods that are scheduled with it.
Implementations
The name of the Fargate profile.
The full Amazon Resource Name (ARN) of the Fargate profile.
The name of the Amazon EKS cluster that the Fargate profile belongs to.
The Unix epoch timestamp in seconds for when the Fargate profile was created.
The Amazon Resource Name (ARN) of the pod execution role to use for pods that match the selectors in the Fargate profile. For more information, see Pod Execution Role in the Amazon EKS User Guide.
The selectors to match for pods to use this Fargate profile.
The current status of the Fargate profile.
The metadata applied to the Fargate profile to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Fargate profile tags do not propagate to any other resources associated with the Fargate profile, such as the pods that are scheduled with it.
Creates a new builder-style object to manufacture FargateProfile