Struct aws_sdk_eks::model::KubernetesNetworkConfigRequest[][src]

#[non_exhaustive]
pub struct KubernetesNetworkConfigRequest { pub service_ipv4_cidr: Option<String>, }
The Kubernetes network configuration for the cluster.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
service_ipv4_cidr: Option<String>

The CIDR block to assign Kubernetes service IP addresses from. If you don't specify a block, Kubernetes assigns addresses from either the 10.100.0.0/16 or 172.20.0.0/16 CIDR blocks. We recommend that you specify a block that does not overlap with resources in other networks that are peered or connected to your VPC. The block must meet the following requirements:

  • Within one of the following private IP address blocks: 10.0.0.0/8, 172.16.0.0/12, or 192.168.0.0/16.

  • Doesn't overlap with any CIDR block assigned to the VPC that you selected for VPC.

  • Between /24 and /12.

You can only specify a custom CIDR block when you create a cluster and can't change this value once the cluster is created.

Implementations

The CIDR block to assign Kubernetes service IP addresses from. If you don't specify a block, Kubernetes assigns addresses from either the 10.100.0.0/16 or 172.20.0.0/16 CIDR blocks. We recommend that you specify a block that does not overlap with resources in other networks that are peered or connected to your VPC. The block must meet the following requirements:

  • Within one of the following private IP address blocks: 10.0.0.0/8, 172.16.0.0/12, or 192.168.0.0/16.

  • Doesn't overlap with any CIDR block assigned to the VPC that you selected for VPC.

  • Between /24 and /12.

You can only specify a custom CIDR block when you create a cluster and can't change this value once the cluster is created.

Creates a new builder-style object to manufacture KubernetesNetworkConfigRequest