Struct aws_sdk_eks::model::KubernetesNetworkConfigResponse [−][src]
#[non_exhaustive]pub struct KubernetesNetworkConfigResponse {
pub service_ipv4_cidr: Option<String>,
}Expand description
The Kubernetes network configuration for the cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_ipv4_cidr: Option<String>The CIDR block that Kubernetes service IP addresses are assigned from. If you didn't specify a CIDR block when you created the cluster, then Kubernetes assigns addresses from either the 10.100.0.0/16 or 172.20.0.0/16 CIDR blocks. If this was specified, then it was specified when the cluster was created and it cannot be changed.
Implementations
The CIDR block that Kubernetes service IP addresses are assigned from. If you didn't specify a CIDR block when you created the cluster, then Kubernetes assigns addresses from either the 10.100.0.0/16 or 172.20.0.0/16 CIDR blocks. If this was specified, then it was specified when the cluster was created and it cannot be changed.
Creates a new builder-style object to manufacture KubernetesNetworkConfigResponse