Struct aws_sdk_eks::model::OidcIdentityProviderConfig [−][src]
#[non_exhaustive]pub struct OidcIdentityProviderConfig {
pub identity_provider_config_name: Option<String>,
pub identity_provider_config_arn: Option<String>,
pub cluster_name: Option<String>,
pub issuer_url: Option<String>,
pub client_id: Option<String>,
pub username_claim: Option<String>,
pub username_prefix: Option<String>,
pub groups_claim: Option<String>,
pub groups_prefix: Option<String>,
pub required_claims: Option<HashMap<String, String>>,
pub tags: Option<HashMap<String, String>>,
pub status: Option<ConfigStatus>,
}Expand description
An object that represents the configuration for an OpenID Connect (OIDC) identity provider.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity_provider_config_name: Option<String>The name of the configuration.
identity_provider_config_arn: Option<String>The ARN of the configuration.
cluster_name: Option<String>The cluster that the configuration is associated to.
issuer_url: Option<String>The URL of the OIDC identity provider that allows the API server to discover public signing keys for verifying tokens.
client_id: Option<String>This is also known as audience. The ID of the client application that makes authentication requests to the OIDC identity provider.
username_claim: Option<String>The JSON Web token (JWT) claim that is used as the username.
username_prefix: Option<String>The prefix that is prepended to username claims to prevent clashes with existing
names. The prefix can't contain system:
groups_claim: Option<String>The JSON web token (JWT) claim that the provider uses to return your groups.
groups_prefix: Option<String>The prefix that is prepended to group claims to prevent clashes with existing names
(such as system: groups). For example, the value oidc: creates
group names like oidc:engineering and oidc:infra. The prefix
can't contain system:
required_claims: Option<HashMap<String, String>>The key-value pairs that describe required claims in the identity token. If set, each claim is verified to be present in the token with a matching value.
The metadata to apply to the provider configuration to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you defined.
status: Option<ConfigStatus>The status of the OIDC identity provider.
Implementations
The name of the configuration.
The ARN of the configuration.
The cluster that the configuration is associated to.
The URL of the OIDC identity provider that allows the API server to discover public signing keys for verifying tokens.
This is also known as audience. The ID of the client application that makes authentication requests to the OIDC identity provider.
The JSON Web token (JWT) claim that is used as the username.
The prefix that is prepended to username claims to prevent clashes with existing
names. The prefix can't contain system:
The JSON web token (JWT) claim that the provider uses to return your groups.
The prefix that is prepended to group claims to prevent clashes with existing names
(such as system: groups). For example, the value oidc: creates
group names like oidc:engineering and oidc:infra. The prefix
can't contain system:
The key-value pairs that describe required claims in the identity token. If set, each claim is verified to be present in the token with a matching value.
The metadata to apply to the provider configuration to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you defined.
The status of the OIDC identity provider.
Creates a new builder-style object to manufacture OidcIdentityProviderConfig