Struct aws_sdk_eks::model::OidcIdentityProviderConfigRequest [−][src]
#[non_exhaustive]pub struct OidcIdentityProviderConfigRequest {
pub identity_provider_config_name: Option<String>,
pub issuer_url: Option<String>,
pub client_id: Option<String>,
pub username_claim: Option<String>,
pub username_prefix: Option<String>,
pub groups_claim: Option<String>,
pub groups_prefix: Option<String>,
pub required_claims: Option<HashMap<String, String>>,
}Expand description
An object representing an OpenID Connect (OIDC) configuration. Before associating an OIDC identity provider to your cluster, review the considerations in Authenticating users for your cluster from an OpenID Connect identity provider in the Amazon EKS User Guide.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity_provider_config_name: Option<String>The name of the OIDC provider configuration.
issuer_url: Option<String>The URL of the OpenID identity provider that allows the API server to discover public
signing keys for verifying tokens. The URL must begin with https:// and
should correspond to the iss claim in the provider's OIDC ID tokens. Per
the OIDC standard, path components are allowed but query parameters are not. Typically
the URL consists of only a hostname, like https://server.example.org or
https://example.com. This URL should point to the level below
.well-known/openid-configuration and must be publicly accessible over
the internet.
client_id: Option<String>This is also known as audience. The ID for the client application that makes authentication requests to the OpenID identity provider.
username_claim: Option<String>The JSON Web Token (JWT) claim to use as the username. The default is
sub, which is expected to be a unique identifier of the end user. You can
choose other claims, such as email or name, depending on the
OpenID identity provider. Claims other than email are prefixed with the
issuer URL to prevent naming clashes with other plug-ins.
username_prefix: Option<String>The prefix that is prepended to username claims to prevent clashes with existing
names. If you do not provide this field, and username is a value other than
email, the prefix defaults to issuerurl#. You can use the
value - to disable all prefixing.
groups_claim: Option<String>The JWT claim that the provider uses to return your groups.
groups_prefix: Option<String>The prefix that is prepended to group claims to prevent clashes with existing names
(such as system: groups). For example, the value oidc: will
create group names like oidc:engineering and
oidc:infra.
required_claims: Option<HashMap<String, String>>The key value pairs that describe required claims in the identity token. If set, each claim is verified to be present in the token with a matching value. For the maximum number of claims that you can require, see Amazon EKS service quotas in the Amazon EKS User Guide.
Implementations
Creates a new builder-style object to manufacture OidcIdentityProviderConfigRequest