#[non_exhaustive]pub struct RegisterClusterInput {
pub name: Option<String>,
pub connector_config: Option<ConnectorConfigRequest>,
pub client_request_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>A unique name for this cluster in your Amazon Web Services Region.
connector_config: Option<ConnectorConfigRequest>The configuration settings required to connect the Kubernetes cluster to the Amazon EKS control plane.
client_request_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Metadata that assists with categorization and organization. Each tag consists of a key and an optional value. You define both. Tags don't propagate to any other cluster or Amazon Web Services resources.
Implementations
Sourceimpl RegisterClusterInput
impl RegisterClusterInput
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
A unique name for this cluster in your Amazon Web Services Region.
Sourcepub fn connector_config(&self) -> Option<&ConnectorConfigRequest>
pub fn connector_config(&self) -> Option<&ConnectorConfigRequest>
The configuration settings required to connect the Kubernetes cluster to the Amazon EKS control plane.
Sourcepub fn client_request_token(&self) -> Option<&str>
pub fn client_request_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
Metadata that assists with categorization and organization. Each tag consists of a key and an optional value. You define both. Tags don't propagate to any other cluster or Amazon Web Services resources.
Sourceimpl RegisterClusterInput
impl RegisterClusterInput
Sourcepub fn builder() -> RegisterClusterInputBuilder
pub fn builder() -> RegisterClusterInputBuilder
Creates a new builder-style object to manufacture RegisterClusterInput.