Struct aws_sdk_eks::output::list_nodegroups_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListNodegroupsOutput
Implementations
Appends an item to nodegroups.
To override the contents of this collection use set_nodegroups.
A list of all of the node groups associated with the specified cluster.
A list of all of the node groups associated with the specified cluster.
The nextToken value to include in a future ListNodegroups
request. When the results of a ListNodegroups request exceed
maxResults, you can use this value to retrieve the next page of
results. This value is null when there are no more results to
return.
The nextToken value to include in a future ListNodegroups
request. When the results of a ListNodegroups request exceed
maxResults, you can use this value to retrieve the next page of
results. This value is null when there are no more results to
return.
Consumes the builder and constructs a ListNodegroupsOutput