Struct aws_sdk_eks::output::ListAddonsOutput [−][src]
#[non_exhaustive]pub struct ListAddonsOutput {
pub addons: Option<Vec<String>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.addons: Option<Vec<String>>A list of available add-ons.
next_token: Option<String>The nextToken value returned from a previous paginated
ListAddonsResponse where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
Implementations
The nextToken value returned from a previous paginated
ListAddonsResponse where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes.
Creates a new builder-style object to manufacture ListAddonsOutput