Struct aws_sdk_eks::output::ListClustersOutput [−][src]
#[non_exhaustive]pub struct ListClustersOutput {
pub clusters: Option<Vec<String>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.clusters: Option<Vec<String>>A list of all of the clusters for your account in the specified Region.
next_token: Option<String>The nextToken value to include in a future ListClusters
request. When the results of a ListClusters request exceed
maxResults, you can use this value to retrieve the next page of
results. This value is null when there are no more results to
return.
Implementations
A list of all of the clusters for your account in the specified Region.
The nextToken value to include in a future ListClusters
request. When the results of a ListClusters request exceed
maxResults, you can use this value to retrieve the next page of
results. This value is null when there are no more results to
return.
Creates a new builder-style object to manufacture ListClustersOutput