Struct aws_sdk_eks::output::ListFargateProfilesOutput [−][src]
#[non_exhaustive]pub struct ListFargateProfilesOutput {
pub fargate_profile_names: Option<Vec<String>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fargate_profile_names: Option<Vec<String>>A list of all of the Fargate profiles associated with the specified cluster.
next_token: Option<String>The nextToken value to include in a future
ListFargateProfiles request. When the results of a
ListFargateProfiles request exceed maxResults, you can use
this value to retrieve the next page of results. This value is null when
there are no more results to return.
Implementations
A list of all of the Fargate profiles associated with the specified cluster.
The nextToken value to include in a future
ListFargateProfiles request. When the results of a
ListFargateProfiles request exceed maxResults, you can use
this value to retrieve the next page of results. This value is null when
there are no more results to return.
Creates a new builder-style object to manufacture ListFargateProfilesOutput