Struct aws_sdk_eks::output::ListIdentityProviderConfigsOutput [−][src]
#[non_exhaustive]pub struct ListIdentityProviderConfigsOutput {
pub identity_provider_configs: Option<Vec<IdentityProviderConfig>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.identity_provider_configs: Option<Vec<IdentityProviderConfig>>The identity provider configurations for the cluster.
next_token: Option<String>The nextToken value returned from a previous paginated
ListIdentityProviderConfigsResponse where maxResults was
used and the results exceeded the value of that parameter. Pagination continues from the
end of the previous results that returned the nextToken value.
Implementations
The identity provider configurations for the cluster.
The nextToken value returned from a previous paginated
ListIdentityProviderConfigsResponse where maxResults was
used and the results exceeded the value of that parameter. Pagination continues from the
end of the previous results that returned the nextToken value.
Creates a new builder-style object to manufacture ListIdentityProviderConfigsOutput