Struct aws_sdk_eks::output::ListUpdatesOutput [−][src]
#[non_exhaustive]pub struct ListUpdatesOutput {
pub update_ids: Option<Vec<String>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_ids: Option<Vec<String>>A list of all the updates for the specified cluster and Region.
next_token: Option<String>The nextToken value to include in a future ListUpdates
request. When the results of a ListUpdates request exceed
maxResults, you can use this value to retrieve the next page of
results. This value is null when there are no more results to
return.
Implementations
A list of all the updates for the specified cluster and Region.
The nextToken value to include in a future ListUpdates
request. When the results of a ListUpdates request exceed
maxResults, you can use this value to retrieve the next page of
results. This value is null when there are no more results to
return.
Creates a new builder-style object to manufacture ListUpdatesOutput