#[non_exhaustive]pub struct EncryptionConfigBuilder { /* private fields */ }Expand description
A builder for EncryptionConfig.
Implementations
Sourceimpl EncryptionConfigBuilder
impl EncryptionConfigBuilder
Sourcepub fn resources(self, input: impl Into<String>) -> Self
👎Deprecated since 2025-03-05: Deprecated. Amazon EKS encrypts all Kubernetes API data by default, so this value no longer determines which resources are encrypted.
pub fn resources(self, input: impl Into<String>) -> Self
Deprecated. Amazon EKS encrypts all Kubernetes API data by default, so this value no longer determines which resources are encrypted.
Appends an item to resources.
To override the contents of this collection use set_resources.
Amazon EKS encrypts all Kubernetes API data with envelope encryption by default for clusters running Kubernetes version 1.28 or higher, so this field no longer affects which resources are encrypted.
Specifies the resources to be encrypted. The only supported value is secrets.
Sourcepub fn set_resources(self, input: Option<Vec<String>>) -> Self
👎Deprecated since 2025-03-05: Deprecated. Amazon EKS encrypts all Kubernetes API data by default, so this value no longer determines which resources are encrypted.
pub fn set_resources(self, input: Option<Vec<String>>) -> Self
Deprecated. Amazon EKS encrypts all Kubernetes API data by default, so this value no longer determines which resources are encrypted.
Amazon EKS encrypts all Kubernetes API data with envelope encryption by default for clusters running Kubernetes version 1.28 or higher, so this field no longer affects which resources are encrypted.
Specifies the resources to be encrypted. The only supported value is secrets.
Sourcepub fn get_resources(&self) -> &Option<Vec<String>>
👎Deprecated since 2025-03-05: Deprecated. Amazon EKS encrypts all Kubernetes API data by default, so this value no longer determines which resources are encrypted.
pub fn get_resources(&self) -> &Option<Vec<String>>
Deprecated. Amazon EKS encrypts all Kubernetes API data by default, so this value no longer determines which resources are encrypted.
Amazon EKS encrypts all Kubernetes API data with envelope encryption by default for clusters running Kubernetes version 1.28 or higher, so this field no longer affects which resources are encrypted.
Specifies the resources to be encrypted. The only supported value is secrets.
Sourcepub fn provider(self, input: Provider) -> Self
pub fn provider(self, input: Provider) -> Self
Key Management Service (KMS) key. Either the ARN or the alias can be used.
Sourcepub fn set_provider(self, input: Option<Provider>) -> Self
pub fn set_provider(self, input: Option<Provider>) -> Self
Key Management Service (KMS) key. Either the ARN or the alias can be used.
Sourcepub fn get_provider(&self) -> &Option<Provider>
pub fn get_provider(&self) -> &Option<Provider>
Key Management Service (KMS) key. Either the ARN or the alias can be used.
Sourcepub fn build(self) -> EncryptionConfig
pub fn build(self) -> EncryptionConfig
Consumes the builder and constructs a EncryptionConfig.