#[non_exhaustive]pub struct KubeControllerManagerVersionConfigBuilder { /* private fields */ }Expand description
A builder for KubeControllerManagerVersionConfig.
Implementations
Sourceimpl KubeControllerManagerVersionConfigBuilder
impl KubeControllerManagerVersionConfigBuilder
Sourcepub fn horizontal_pod_autoscaler_controller_config(
self,
input: HorizontalPodAutoscalerControllerVersionConfig,
) -> Self
pub fn horizontal_pod_autoscaler_controller_config( self, input: HorizontalPodAutoscalerControllerVersionConfig, ) -> Self
The horizontal pod autoscaler controller configuration with default value and constraints.
Sourcepub fn set_horizontal_pod_autoscaler_controller_config(
self,
input: Option<HorizontalPodAutoscalerControllerVersionConfig>,
) -> Self
pub fn set_horizontal_pod_autoscaler_controller_config( self, input: Option<HorizontalPodAutoscalerControllerVersionConfig>, ) -> Self
The horizontal pod autoscaler controller configuration with default value and constraints.
Sourcepub fn get_horizontal_pod_autoscaler_controller_config(
&self,
) -> &Option<HorizontalPodAutoscalerControllerVersionConfig>
pub fn get_horizontal_pod_autoscaler_controller_config( &self, ) -> &Option<HorizontalPodAutoscalerControllerVersionConfig>
The horizontal pod autoscaler controller configuration with default value and constraints.
Sourcepub fn build(self) -> KubeControllerManagerVersionConfig
pub fn build(self) -> KubeControllerManagerVersionConfig
Consumes the builder and constructs a KubeControllerManagerVersionConfig.