#[non_exhaustive]pub struct NodeResourcesFitConfigBuilder { /* private fields */ }Expand description
A builder for NodeResourcesFitConfig.
Implementations
Sourceimpl NodeResourcesFitConfigBuilder
impl NodeResourcesFitConfigBuilder
Sourcepub fn scoring_strategy(self, input: ScoringStrategy) -> Self
pub fn scoring_strategy(self, input: ScoringStrategy) -> Self
The scoring strategy used to rank nodes during scheduling.
Sourcepub fn set_scoring_strategy(self, input: Option<ScoringStrategy>) -> Self
pub fn set_scoring_strategy(self, input: Option<ScoringStrategy>) -> Self
The scoring strategy used to rank nodes during scheduling.
Sourcepub fn get_scoring_strategy(&self) -> &Option<ScoringStrategy>
pub fn get_scoring_strategy(&self) -> &Option<ScoringStrategy>
The scoring strategy used to rank nodes during scheduling.
Sourcepub fn build(self) -> NodeResourcesFitConfig
pub fn build(self) -> NodeResourcesFitConfig
Consumes the builder and constructs a NodeResourcesFitConfig.