#[non_exhaustive]pub struct PodGcControllerConfigResponseBuilder { /* private fields */ }Expand description
A builder for PodGcControllerConfigResponse.
Implementations
Sourceimpl PodGcControllerConfigResponseBuilder
impl PodGcControllerConfigResponseBuilder
Sourcepub fn terminated_pod_gc_threshold(self, input: i32) -> Self
pub fn terminated_pod_gc_threshold(self, input: i32) -> Self
The number of terminated pods that can exist before the garbage collector starts deleting them.
Sourcepub fn set_terminated_pod_gc_threshold(self, input: Option<i32>) -> Self
pub fn set_terminated_pod_gc_threshold(self, input: Option<i32>) -> Self
The number of terminated pods that can exist before the garbage collector starts deleting them.
Sourcepub fn get_terminated_pod_gc_threshold(&self) -> &Option<i32>
pub fn get_terminated_pod_gc_threshold(&self) -> &Option<i32>
The number of terminated pods that can exist before the garbage collector starts deleting them.
Sourcepub fn build(self) -> PodGcControllerConfigResponse
pub fn build(self) -> PodGcControllerConfigResponse
Consumes the builder and constructs a PodGcControllerConfigResponse.