#[non_exhaustive]pub struct PodGcControllerVersionConfigBuilder { /* private fields */ }Expand description
A builder for PodGcControllerVersionConfig.
Implementations
Sourceimpl PodGcControllerVersionConfigBuilder
impl PodGcControllerVersionConfigBuilder
Sourcepub fn terminated_pod_gc_threshold(self, input: IntegerParameterConfig) -> Self
pub fn terminated_pod_gc_threshold(self, input: IntegerParameterConfig) -> Self
The terminated pod garbage collection threshold configuration with default value and constraints.
Sourcepub fn set_terminated_pod_gc_threshold(
self,
input: Option<IntegerParameterConfig>,
) -> Self
pub fn set_terminated_pod_gc_threshold( self, input: Option<IntegerParameterConfig>, ) -> Self
The terminated pod garbage collection threshold configuration with default value and constraints.
Sourcepub fn get_terminated_pod_gc_threshold(&self) -> &Option<IntegerParameterConfig>
pub fn get_terminated_pod_gc_threshold(&self) -> &Option<IntegerParameterConfig>
The terminated pod garbage collection threshold configuration with default value and constraints.
Sourcepub fn build(self) -> PodGcControllerVersionConfig
pub fn build(self) -> PodGcControllerVersionConfig
Consumes the builder and constructs a PodGcControllerVersionConfig.