#[non_exhaustive]pub struct WarmPoolConfigBuilder { /* private fields */ }Expand description
A builder for WarmPoolConfig.
Implementations
Sourceimpl WarmPoolConfigBuilder
impl WarmPoolConfigBuilder
Sourcepub fn enabled(self, input: bool) -> Self
pub fn enabled(self, input: bool) -> Self
Specifies whether to attach warm pools on the managed node group. Set to true to enable the warm pool, or false to disable and remove it. If not specified during an update, the current value is preserved.
Sourcepub fn set_enabled(self, input: Option<bool>) -> Self
pub fn set_enabled(self, input: Option<bool>) -> Self
Specifies whether to attach warm pools on the managed node group. Set to true to enable the warm pool, or false to disable and remove it. If not specified during an update, the current value is preserved.
Sourcepub fn get_enabled(&self) -> &Option<bool>
pub fn get_enabled(&self) -> &Option<bool>
Specifies whether to attach warm pools on the managed node group. Set to true to enable the warm pool, or false to disable and remove it. If not specified during an update, the current value is preserved.
Sourcepub fn min_size(self, input: i32) -> Self
pub fn min_size(self, input: i32) -> Self
The minimum number of instances to maintain in the warm pool. Default: 0. Size your warm pool based on scaling patterns to balance cost and availability. Start with 10-20% of expected peak capacity.
Sourcepub fn set_min_size(self, input: Option<i32>) -> Self
pub fn set_min_size(self, input: Option<i32>) -> Self
The minimum number of instances to maintain in the warm pool. Default: 0. Size your warm pool based on scaling patterns to balance cost and availability. Start with 10-20% of expected peak capacity.
Sourcepub fn get_min_size(&self) -> &Option<i32>
pub fn get_min_size(&self) -> &Option<i32>
The minimum number of instances to maintain in the warm pool. Default: 0. Size your warm pool based on scaling patterns to balance cost and availability. Start with 10-20% of expected peak capacity.
Sourcepub fn max_group_prepared_capacity(self, input: i32) -> Self
pub fn max_group_prepared_capacity(self, input: i32) -> Self
The maximum total number of instances across the warm pool and Auto Scaling group combined. This value controls the total prepared capacity available for your node group.
Sourcepub fn set_max_group_prepared_capacity(self, input: Option<i32>) -> Self
pub fn set_max_group_prepared_capacity(self, input: Option<i32>) -> Self
The maximum total number of instances across the warm pool and Auto Scaling group combined. This value controls the total prepared capacity available for your node group.
Sourcepub fn get_max_group_prepared_capacity(&self) -> &Option<i32>
pub fn get_max_group_prepared_capacity(&self) -> &Option<i32>
The maximum total number of instances across the warm pool and Auto Scaling group combined. This value controls the total prepared capacity available for your node group.
Sourcepub fn pool_state(self, input: WarmPoolState) -> Self
pub fn pool_state(self, input: WarmPoolState) -> Self
The desired state for warm pool instances. Default: Stopped. Valid values are Stopped (most cost-effective with EBS storage costs only), Running (fastest transition time with full EC2 costs), and Hibernated (balance between cost and speed, only supported on specific instance types). Warm pool instances in the Hibernated state are not supported with Bottlerocket AMIs.
Sourcepub fn set_pool_state(self, input: Option<WarmPoolState>) -> Self
pub fn set_pool_state(self, input: Option<WarmPoolState>) -> Self
The desired state for warm pool instances. Default: Stopped. Valid values are Stopped (most cost-effective with EBS storage costs only), Running (fastest transition time with full EC2 costs), and Hibernated (balance between cost and speed, only supported on specific instance types). Warm pool instances in the Hibernated state are not supported with Bottlerocket AMIs.
Sourcepub fn get_pool_state(&self) -> &Option<WarmPoolState>
pub fn get_pool_state(&self) -> &Option<WarmPoolState>
The desired state for warm pool instances. Default: Stopped. Valid values are Stopped (most cost-effective with EBS storage costs only), Running (fastest transition time with full EC2 costs), and Hibernated (balance between cost and speed, only supported on specific instance types). Warm pool instances in the Hibernated state are not supported with Bottlerocket AMIs.
Sourcepub fn reuse_on_scale_in(self, input: bool) -> Self
pub fn reuse_on_scale_in(self, input: bool) -> Self
Indicates whether instances should return to the warm pool during scale-in events instead of being terminated. Default: false. Enable this to reduce costs by reusing instances. This feature is not supported for Bottlerocket AMIs.
Sourcepub fn set_reuse_on_scale_in(self, input: Option<bool>) -> Self
pub fn set_reuse_on_scale_in(self, input: Option<bool>) -> Self
Indicates whether instances should return to the warm pool during scale-in events instead of being terminated. Default: false. Enable this to reduce costs by reusing instances. This feature is not supported for Bottlerocket AMIs.
Sourcepub fn get_reuse_on_scale_in(&self) -> &Option<bool>
pub fn get_reuse_on_scale_in(&self) -> &Option<bool>
Indicates whether instances should return to the warm pool during scale-in events instead of being terminated. Default: false. Enable this to reduce costs by reusing instances. This feature is not supported for Bottlerocket AMIs.
Sourcepub fn build(self) -> WarmPoolConfig
pub fn build(self) -> WarmPoolConfig
Consumes the builder and constructs a WarmPoolConfig.