#[non_exhaustive]pub struct ResourceNotFoundException {
pub cluster_name: Option<String>,
pub nodegroup_name: Option<String>,
pub fargate_profile_name: Option<String>,
pub addon_name: Option<String>,
pub subscription_id: Option<String>,
pub message: Option<String>,
/* private fields */
}Expand description
The specified resource could not be found. You can view your available clusters with ListClusters. You can view your available managed node groups with ListNodegroups. Amazon EKS clusters and node groups are Amazon Web Services Region specific.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_name: Option<String>The Amazon EKS cluster associated with the exception.
nodegroup_name: Option<String>The Amazon EKS managed node group associated with the exception.
fargate_profile_name: Option<String>The Fargate profile associated with the exception.
addon_name: Option<String>The Amazon EKS add-on name associated with the exception.
subscription_id: Option<String>The Amazon EKS subscription ID with the exception.
message: Option<String>The Amazon EKS message associated with the exception.
Implementations
Sourceimpl ResourceNotFoundException
impl ResourceNotFoundException
Sourcepub fn cluster_name(&self) -> Option<&str>
pub fn cluster_name(&self) -> Option<&str>
The Amazon EKS cluster associated with the exception.
Sourcepub fn nodegroup_name(&self) -> Option<&str>
pub fn nodegroup_name(&self) -> Option<&str>
The Amazon EKS managed node group associated with the exception.
Sourcepub fn fargate_profile_name(&self) -> Option<&str>
pub fn fargate_profile_name(&self) -> Option<&str>
The Fargate profile associated with the exception.
Sourcepub fn addon_name(&self) -> Option<&str>
pub fn addon_name(&self) -> Option<&str>
The Amazon EKS add-on name associated with the exception.
Sourcepub fn subscription_id(&self) -> Option<&str>
pub fn subscription_id(&self) -> Option<&str>
The Amazon EKS subscription ID with the exception.
Sourceimpl ResourceNotFoundException
impl ResourceNotFoundException
Sourcepub fn builder() -> ResourceNotFoundExceptionBuilder
pub fn builder() -> ResourceNotFoundExceptionBuilder
Creates a new builder-style object to manufacture ResourceNotFoundException.