#[non_exhaustive]pub struct AllowedValuesConstraint {
pub allowed_values: Option<Vec<String>>,
}Expand description
A constraint specifying the allowed values for a parameter.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.allowed_values: Option<Vec<String>>The list of allowed values.
Implementations
Sourceimpl AllowedValuesConstraint
impl AllowedValuesConstraint
Sourcepub fn allowed_values(&self) -> &[String]
pub fn allowed_values(&self) -> &[String]
The list of allowed values.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowed_values.is_none().
Sourceimpl AllowedValuesConstraint
impl AllowedValuesConstraint
Sourcepub fn builder() -> AllowedValuesConstraintBuilder
pub fn builder() -> AllowedValuesConstraintBuilder
Creates a new builder-style object to manufacture AllowedValuesConstraint.