#[non_exhaustive]pub struct Cancellation {
pub status: Option<CancellationStatus>,
pub reason: Option<String>,
}Expand description
Contains information about the latest cancellation of an update to an Amazon EKS cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<CancellationStatus>The current status of the cancellation. Valid values are InProgress, Failed, and Successful.
reason: Option<String>A message providing additional details about the cancellation, such as the reason for the cancellation or failure details.
Implementations
Sourceimpl Cancellation
impl Cancellation
Sourcepub fn status(&self) -> Option<&CancellationStatus>
pub fn status(&self) -> Option<&CancellationStatus>
The current status of the cancellation. Valid values are InProgress, Failed, and Successful.
Sourceimpl Cancellation
impl Cancellation
Sourcepub fn builder() -> CancellationBuilder
pub fn builder() -> CancellationBuilder
Creates a new builder-style object to manufacture Cancellation.