#[non_exhaustive]pub struct ControlPlaneScalingTierInfo {
pub tier_name: Option<String>,
pub api_request_concurrency: Option<i32>,
pub pod_scheduling_rate_per_second: Option<i32>,
pub cluster_database_size_gb: Option<i32>,
pub control_plane_component_config_overrides: Option<ControlPlaneConfigInfo>,
}Expand description
Information about a provisioned control plane scaling tier.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tier_name: Option<String>The name of the scaling tier.
api_request_concurrency: Option<i32>The maximum API request concurrency supported by this tier.
pod_scheduling_rate_per_second: Option<i32>The maximum pod scheduling rate per second supported by this tier.
cluster_database_size_gb: Option<i32>The maximum cluster database size in GB supported by this tier.
control_plane_component_config_overrides: Option<ControlPlaneConfigInfo>The control plane component configuration overrides specific to this scaling tier.
Implementations
Sourceimpl ControlPlaneScalingTierInfo
impl ControlPlaneScalingTierInfo
Sourcepub fn api_request_concurrency(&self) -> Option<i32>
pub fn api_request_concurrency(&self) -> Option<i32>
The maximum API request concurrency supported by this tier.
Sourcepub fn pod_scheduling_rate_per_second(&self) -> Option<i32>
pub fn pod_scheduling_rate_per_second(&self) -> Option<i32>
The maximum pod scheduling rate per second supported by this tier.
Sourcepub fn cluster_database_size_gb(&self) -> Option<i32>
pub fn cluster_database_size_gb(&self) -> Option<i32>
The maximum cluster database size in GB supported by this tier.
Sourcepub fn control_plane_component_config_overrides(
&self,
) -> Option<&ControlPlaneConfigInfo>
pub fn control_plane_component_config_overrides( &self, ) -> Option<&ControlPlaneConfigInfo>
The control plane component configuration overrides specific to this scaling tier.
Sourceimpl ControlPlaneScalingTierInfo
impl ControlPlaneScalingTierInfo
Sourcepub fn builder() -> ControlPlaneScalingTierInfoBuilder
pub fn builder() -> ControlPlaneScalingTierInfoBuilder
Creates a new builder-style object to manufacture ControlPlaneScalingTierInfo.