#[non_exhaustive]pub struct HorizontalPodAutoscalerControllerConfigRequest {
pub horizontal_pod_autoscaler_sync_period: Option<String>,
}Expand description
The horizontal pod autoscaler controller configuration for the Kubernetes controller manager.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.horizontal_pod_autoscaler_sync_period: Option<String>The interval between each sync of the horizontal pod autoscaler. Valid values are single-unit durations such as 15s or 1m.
Implementations
Sourceimpl HorizontalPodAutoscalerControllerConfigRequest
impl HorizontalPodAutoscalerControllerConfigRequest
Sourcepub fn horizontal_pod_autoscaler_sync_period(&self) -> Option<&str>
pub fn horizontal_pod_autoscaler_sync_period(&self) -> Option<&str>
The interval between each sync of the horizontal pod autoscaler. Valid values are single-unit durations such as 15s or 1m.
Sourceimpl HorizontalPodAutoscalerControllerConfigRequest
impl HorizontalPodAutoscalerControllerConfigRequest
Sourcepub fn builder() -> HorizontalPodAutoscalerControllerConfigRequestBuilder
pub fn builder() -> HorizontalPodAutoscalerControllerConfigRequestBuilder
Creates a new builder-style object to manufacture HorizontalPodAutoscalerControllerConfigRequest.