#[non_exhaustive]pub struct PodGcControllerConfigResponse {
pub terminated_pod_gc_threshold: Option<i32>,
}Expand description
The pod garbage collection controller configuration for the Kubernetes controller manager.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.terminated_pod_gc_threshold: Option<i32>The number of terminated pods that can exist before the garbage collector starts deleting them.
Implementations
Sourceimpl PodGcControllerConfigResponse
impl PodGcControllerConfigResponse
Sourcepub fn terminated_pod_gc_threshold(&self) -> Option<i32>
pub fn terminated_pod_gc_threshold(&self) -> Option<i32>
The number of terminated pods that can exist before the garbage collector starts deleting them.
Sourceimpl PodGcControllerConfigResponse
impl PodGcControllerConfigResponse
Sourcepub fn builder() -> PodGcControllerConfigResponseBuilder
pub fn builder() -> PodGcControllerConfigResponseBuilder
Creates a new builder-style object to manufacture PodGcControllerConfigResponse.