#[non_exhaustive]pub struct RollbackConfig {
pub timeout_minutes: Option<i32>,
}Expand description
The rollback configuration for the cluster version rollback.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.timeout_minutes: Option<i32>The length of time in minutes to wait before cancelling the update. Timeout is a minimum-bound property, meaning the timeout occurs no sooner than the time you specify, but can occur shortly thereafter. This value can be between 120 (2 hours) and 10080 (7 days). Default: 720 (12 hours) if not specified.
Implementations
Sourceimpl RollbackConfig
impl RollbackConfig
Sourcepub fn timeout_minutes(&self) -> Option<i32>
pub fn timeout_minutes(&self) -> Option<i32>
The length of time in minutes to wait before cancelling the update. Timeout is a minimum-bound property, meaning the timeout occurs no sooner than the time you specify, but can occur shortly thereafter. This value can be between 120 (2 hours) and 10080 (7 days). Default: 720 (12 hours) if not specified.
Sourceimpl RollbackConfig
impl RollbackConfig
Sourcepub fn builder() -> RollbackConfigBuilder
pub fn builder() -> RollbackConfigBuilder
Creates a new builder-style object to manufacture RollbackConfig.