Struct aws_sdk_eks::client::fluent_builders::ListIdentityProviderConfigs [−][src]
pub struct ListIdentityProviderConfigs<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to ListIdentityProviderConfigs.
A list of identity provider configurations.
Implementations
impl<C, M, R> ListIdentityProviderConfigs<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> ListIdentityProviderConfigs<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<ListIdentityProviderConfigsOutput, SdkError<ListIdentityProviderConfigsError>> where
R::Policy: SmithyRetryPolicy<ListIdentityProviderConfigsInputOperationOutputAlias, ListIdentityProviderConfigsOutput, ListIdentityProviderConfigsError, ListIdentityProviderConfigsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<ListIdentityProviderConfigsOutput, SdkError<ListIdentityProviderConfigsError>> where
R::Policy: SmithyRetryPolicy<ListIdentityProviderConfigsInputOperationOutputAlias, ListIdentityProviderConfigsOutput, ListIdentityProviderConfigsError, ListIdentityProviderConfigsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The cluster name that you want to list identity provider configurations for.
The cluster name that you want to list identity provider configurations for.
The maximum number of identity provider configurations returned by
ListIdentityProviderConfigs in paginated output. When you use this
parameter, ListIdentityProviderConfigs returns only maxResults
results in a single page along with a nextToken response element. You can
see the remaining results of the initial request by sending another
ListIdentityProviderConfigs request with the returned
nextToken value. This value can be between 1 and
100. If you don't use this parameter,
ListIdentityProviderConfigs returns up to 100 results
and a nextToken value, if applicable.
The maximum number of identity provider configurations returned by
ListIdentityProviderConfigs in paginated output. When you use this
parameter, ListIdentityProviderConfigs returns only maxResults
results in a single page along with a nextToken response element. You can
see the remaining results of the initial request by sending another
ListIdentityProviderConfigs request with the returned
nextToken value. This value can be between 1 and
100. If you don't use this parameter,
ListIdentityProviderConfigs returns up to 100 results
and a nextToken value, if applicable.
The nextToken value returned from a previous paginated
IdentityProviderConfigsRequest where maxResults was used
and the results exceeded the value of that parameter. Pagination continues from the end
of the previous results that returned the nextToken value.
The nextToken value returned from a previous paginated
IdentityProviderConfigsRequest where maxResults was used
and the results exceeded the value of that parameter. Pagination continues from the end
of the previous results that returned the nextToken value.