Struct aws_sdk_eks::client::fluent_builders::ListUpdates [−][src]
pub struct ListUpdates<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to ListUpdates.
Lists the updates associated with an Amazon EKS cluster or managed node group in your Amazon Web Services account, in the specified Region.
Implementations
impl<C, M, R> ListUpdates<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> ListUpdates<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<ListUpdatesOutput, SdkError<ListUpdatesError>> where
R::Policy: SmithyRetryPolicy<ListUpdatesInputOperationOutputAlias, ListUpdatesOutput, ListUpdatesError, ListUpdatesInputOperationRetryAlias>,
pub async fn send(self) -> Result<ListUpdatesOutput, SdkError<ListUpdatesError>> where
R::Policy: SmithyRetryPolicy<ListUpdatesInputOperationOutputAlias, ListUpdatesOutput, ListUpdatesError, ListUpdatesInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the Amazon EKS cluster to list updates for.
The name of the Amazon EKS cluster to list updates for.
The name of the Amazon EKS managed node group to list updates for.
The name of the Amazon EKS managed node group to list updates for.
The names of the installed add-ons that have available updates.
The names of the installed add-ons that have available updates.
The nextToken value returned from a previous paginated
ListUpdates request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
The nextToken value returned from a previous paginated
ListUpdates request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues from the end of the
previous results that returned the nextToken value.
The maximum number of update results returned by ListUpdates in paginated
output. When you use this parameter, ListUpdates returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListUpdates request with the returned nextToken value.
This value can be between 1 and 100. If you don't use this
parameter, ListUpdates returns up to 100 results and a
nextToken value if applicable.
The maximum number of update results returned by ListUpdates in paginated
output. When you use this parameter, ListUpdates returns only
maxResults results in a single page along with a nextToken
response element. You can see the remaining results of the initial request by sending
another ListUpdates request with the returned nextToken value.
This value can be between 1 and 100. If you don't use this
parameter, ListUpdates returns up to 100 results and a
nextToken value if applicable.