Struct aws_sdk_eks::client::Client [−][src]
pub struct Client<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
An ergonomic service client for AWSWesleyFrontend.
This client allows ergonomic access to a AWSWesleyFrontend-shaped service.
Each method corresponds to an endpoint defined in the service’s Smithy model,
and the request and response shapes are auto-generated from that same model.
Using a Client
Once you have a client set up, you can access the service’s endpoints
by calling the appropriate method on Client. Each such method
returns a request builder for that endpoint, with methods for setting
the various fields of the request. Once your request is complete, use
the send method to send the request. send returns a future, which
you then have to .await to get the service’s response.
Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AssociateEncryptionConfig operation.
See AssociateEncryptionConfig for more information about the
operation and its arguments.
Constructs a fluent builder for the AssociateIdentityProviderConfig operation.
See AssociateIdentityProviderConfig for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateAddon operation.
See CreateAddon for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateCluster operation.
See CreateCluster for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateFargateProfile operation.
See CreateFargateProfile for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateNodegroup operation.
See CreateNodegroup for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteAddon operation.
See DeleteAddon for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteCluster operation.
See DeleteCluster for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteFargateProfile operation.
See DeleteFargateProfile for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteNodegroup operation.
See DeleteNodegroup for more information about the
operation and its arguments.
Constructs a fluent builder for the DeregisterCluster operation.
See DeregisterCluster for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeAddon operation.
See DescribeAddon for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeAddonVersions operation.
See DescribeAddonVersions for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeCluster operation.
See DescribeCluster for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeFargateProfile operation.
See DescribeFargateProfile for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeIdentityProviderConfig operation.
See DescribeIdentityProviderConfig for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeNodegroup operation.
See DescribeNodegroup for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeUpdate operation.
See DescribeUpdate for more information about the
operation and its arguments.
pub fn disassociate_identity_provider_config(
&self
) -> DisassociateIdentityProviderConfig<C, M, R>
pub fn disassociate_identity_provider_config(
&self
) -> DisassociateIdentityProviderConfig<C, M, R>
Constructs a fluent builder for the DisassociateIdentityProviderConfig operation.
See DisassociateIdentityProviderConfig for more information about the
operation and its arguments.
Constructs a fluent builder for the ListAddons operation.
See ListAddons for more information about the
operation and its arguments.
Constructs a fluent builder for the ListClusters operation.
See ListClusters for more information about the
operation and its arguments.
Constructs a fluent builder for the ListFargateProfiles operation.
See ListFargateProfiles for more information about the
operation and its arguments.
Constructs a fluent builder for the ListIdentityProviderConfigs operation.
See ListIdentityProviderConfigs for more information about the
operation and its arguments.
Constructs a fluent builder for the ListNodegroups operation.
See ListNodegroups for more information about the
operation and its arguments.
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the ListUpdates operation.
See ListUpdates for more information about the
operation and its arguments.
Constructs a fluent builder for the RegisterCluster operation.
See RegisterCluster for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateAddon operation.
See UpdateAddon for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateClusterConfig operation.
See UpdateClusterConfig for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateClusterVersion operation.
See UpdateClusterVersion for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateNodegroupConfig operation.
See UpdateNodegroupConfig for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateNodegroupVersion operation.
See UpdateNodegroupVersion for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.