Struct aws_sdk_eks::input::delete_addon_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DeleteAddonInput
Implementations
The name of the cluster to delete the add-on from.
The name of the cluster to delete the add-on from.
The name of the add-on. The name must match one of the names returned by
ListAddons
.
The name of the add-on. The name must match one of the names returned by
ListAddons
.
Specifying this option preserves the add-on software on your cluster but Amazon EKS stops managing any settings for the add-on. If an IAM account is associated with the add-on, it is not removed.
Specifying this option preserves the add-on software on your cluster but Amazon EKS stops managing any settings for the add-on. If an IAM account is associated with the add-on, it is not removed.
Consumes the builder and constructs a DeleteAddonInput