Struct aws_sdk_eks::model::NodegroupScalingConfig [−][src]
#[non_exhaustive]pub struct NodegroupScalingConfig {
pub min_size: Option<i32>,
pub max_size: Option<i32>,
pub desired_size: Option<i32>,
}Expand description
An object representing the scaling configuration details for the Auto Scaling group that is associated with your node group. When creating a node group, you must specify all or none of the properties. When updating a node group, you can specify any or none of the properties.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min_size: Option<i32>The minimum number of nodes that the managed node group can scale in to.
max_size: Option<i32>The maximum number of nodes that the managed node group can scale out to. For information about the maximum number that you can specify, see Amazon EKS service quotas in the Amazon EKS User Guide.
desired_size: Option<i32>The current number of nodes that the managed node group should maintain.
Implementations
Creates a new builder-style object to manufacture NodegroupScalingConfig