#[non_exhaustive]pub struct WarmPoolConfig {
pub enabled: Option<bool>,
pub min_size: Option<i32>,
pub max_group_prepared_capacity: Option<i32>,
pub pool_state: Option<WarmPoolState>,
pub reuse_on_scale_in: Option<bool>,
}Expand description
The configuration for an Amazon EC2 Auto Scaling warm pool attached to an Amazon EKS managed node group. Warm pools maintain pre-initialized EC2 instances alongside your Auto Scaling group that have already completed the bootup initialization process and can be kept in a Stopped, Running, or Hibernated state.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>Specifies whether to attach warm pools on the managed node group. Set to true to enable the warm pool, or false to disable and remove it. If not specified during an update, the current value is preserved.
min_size: Option<i32>The minimum number of instances to maintain in the warm pool. Default: 0. Size your warm pool based on scaling patterns to balance cost and availability. Start with 10-20% of expected peak capacity.
max_group_prepared_capacity: Option<i32>The maximum total number of instances across the warm pool and Auto Scaling group combined. This value controls the total prepared capacity available for your node group.
pool_state: Option<WarmPoolState>The desired state for warm pool instances. Default: Stopped. Valid values are Stopped (most cost-effective with EBS storage costs only), Running (fastest transition time with full EC2 costs), and Hibernated (balance between cost and speed, only supported on specific instance types). Warm pool instances in the Hibernated state are not supported with Bottlerocket AMIs.
reuse_on_scale_in: Option<bool>Indicates whether instances should return to the warm pool during scale-in events instead of being terminated. Default: false. Enable this to reduce costs by reusing instances. This feature is not supported for Bottlerocket AMIs.
Implementations
Sourceimpl WarmPoolConfig
impl WarmPoolConfig
Sourcepub fn enabled(&self) -> Option<bool>
pub fn enabled(&self) -> Option<bool>
Specifies whether to attach warm pools on the managed node group. Set to true to enable the warm pool, or false to disable and remove it. If not specified during an update, the current value is preserved.
Sourcepub fn min_size(&self) -> Option<i32>
pub fn min_size(&self) -> Option<i32>
The minimum number of instances to maintain in the warm pool. Default: 0. Size your warm pool based on scaling patterns to balance cost and availability. Start with 10-20% of expected peak capacity.
Sourcepub fn max_group_prepared_capacity(&self) -> Option<i32>
pub fn max_group_prepared_capacity(&self) -> Option<i32>
The maximum total number of instances across the warm pool and Auto Scaling group combined. This value controls the total prepared capacity available for your node group.
Sourcepub fn pool_state(&self) -> Option<&WarmPoolState>
pub fn pool_state(&self) -> Option<&WarmPoolState>
The desired state for warm pool instances. Default: Stopped. Valid values are Stopped (most cost-effective with EBS storage costs only), Running (fastest transition time with full EC2 costs), and Hibernated (balance between cost and speed, only supported on specific instance types). Warm pool instances in the Hibernated state are not supported with Bottlerocket AMIs.
Sourcepub fn reuse_on_scale_in(&self) -> Option<bool>
pub fn reuse_on_scale_in(&self) -> Option<bool>
Indicates whether instances should return to the warm pool during scale-in events instead of being terminated. Default: false. Enable this to reduce costs by reusing instances. This feature is not supported for Bottlerocket AMIs.
Sourceimpl WarmPoolConfig
impl WarmPoolConfig
Sourcepub fn builder() -> WarmPoolConfigBuilder
pub fn builder() -> WarmPoolConfigBuilder
Creates a new builder-style object to manufacture WarmPoolConfig.